MethodChannelCliqit class

An implementation of CliqitPlatform that uses method channels.

Inheritance

Constructors

MethodChannelCliqit()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
onDataReceived Stream<CliqitDataModel?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
override
init(String apiKey) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
trackEvent(String event, {Map<String, dynamic>? data, String? userId}) Future<void>
override
validateApi() Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited