CliqitPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- CliqitPlatform
- Implementers
Constructors
- CliqitPlatform()
- Constructs a CliqitPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onDataReceived
→ Stream<
CliqitDataModel?> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
init(
String apiKey) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trackEvent(
String event, {Map< String, dynamic> ? data, String? userId}) → Future<void> -
validateApi(
) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ CliqitPlatform
-
The default instance of CliqitPlatform to use.
getter/setter pair