CliqitWeb class
A web implementation of the CliqitPlatform of the Cliqit plugin.
- Inheritance
-
- Object
- PlatformInterface
- CliqitPlatform
- CliqitWeb
Constructors
- CliqitWeb()
- Constructs a CliqitWeb
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onDataReceived
→ Stream<
CliqitDataModel?> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
Returns a String containing the version of the platform.
override
-
init(
String apiKey) → Future< void> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trackEvent(
String event, {Map< String, dynamic> ? data, String? userId}) → Future<void> -
inherited
-
validateApi(
) → Future< void> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void