CliqitDataModel class
Represents the data received from the Cliqit SDK, including deep links, deferred match outcomes, and verification results.
Constructors
-
CliqitDataModel({String? url, String? path, bool isDeferred = false, String? source, Map<
String, dynamic> parameters = const {}, String? clickSessionId, bool? status, String? destinationPath, String? slug, String? appName, String? appId, String? mismatchMessage, String? error, String? message, bool? isDeepLink, bool? matched, String? tier, String? confidence, double? score}) - CliqitDataModel.fromMap(Map map)
-
factory
Properties
- appId → String?
-
final
- appName → String?
-
final
- clickSessionId → String?
-
final
- confidence → String?
-
final
- destinationPath → String?
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDeepLink → bool?
-
final
- isDeferred → bool
-
final
- matched → bool?
-
final
- message → String?
-
final
- mismatchMessage → String?
-
final
-
parameters
→ Map<
String, dynamic> -
final
- path → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → double?
-
final
- slug → String?
-
final
- source → String?
-
final
- status → bool?
-
final
- tier → String?
-
final
- url → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited